EvalDeT
=======

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   start
   guide/index
   reference/index

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
